@@ -10,7 +10,7 @@ def main(config: dict):
 	major, minor, patch = version.split(".")
 
 	# Setup enumerate and resolve functions
-	write_to_file(f"{config['datapack_functions']}/v{version}/load/enumerate.mcfunction", f"""
+	write_to_versioned_file(config, "load/enumerate", f"""
 # If current major is too low, set it to the current major
 execute unless score #{namespace}.major load.status matches {major}.. run scoreboard players set #{namespace}.major load.status {major}
 
@@ -20,7 +20,7 @@ execute if score #{namespace}.major load.status matches {major} unless score #{n
 # If current patch is too low, set it to the current patch (only if major and minor are correct)
 execute if score #{namespace}.major load.status matches {major} if score #{namespace}.minor load.status matches {minor} unless score #{namespace}.patch load.status matches {patch}.. run scoreboard players set #{namespace}.patch load.status {patch}
 """)
-	write_to_file(f"{config['datapack_functions']}/v{version}/load/resolve.mcfunction", f"""
+	write_to_versioned_file(config, "load/resolve", f"""
 # If correct version, load the datapack
 execute if score #{namespace}.major load.status matches {major} if score #{namespace}.minor load.status matches {minor} if score #{namespace}.patch load.status matches {patch} run function {namespace}:v{version}/load/main
 """)
@@ -30,7 +30,7 @@ execute if score #{namespace}.major load.status matches {major} if score #{names
 	write_to_file(f"{config['build_datapack']}/data/{namespace}/tags/function/resolve.json", super_json_dump({"values": [f"{namespace}:v{version}/load/resolve"]}))
 
 	# Setup load main function
-	write_to_file(f"{config['datapack_functions']}/v{version}/load/main.mcfunction", f"""
+	write_to_versioned_file(config, "load/main", f"""
 # Avoiding multiple executions of the same load function
 execute unless score #{namespace}.loaded load.status matches 1 run function {namespace}:v{version}/load/secondary
 
@@ -52,9 +52,9 @@ execute unless score #{namespace}.loaded load.status matches 1 run function {nam
 			items_storage += f"data modify storage {namespace}:items all.{item} set value " + super_json_dump(mc_data, max_level = 0)
 		pass
 
-	write_to_file(f"{config['datapack_functions']}/v{version}/load/confirm_load.mcfunction", f"""
+	write_to_load_file(config, f"""
+# Confirm load
 tellraw @a[tag=convention.debug] {{"text":"[Loaded {config['project_name']} v{version}]","color":"green"}}
-
 scoreboard players set #{namespace}.loaded load.status 1
 """ + items_storage)
 
